@@ -1565,7 +1565,11 @@ _gpgrt_estream_format (estream_printf_out_t outfnc,
   else
     {
       for (validx=0; validx < DIM(valuetable_buffer); validx++)
-        valuetable[validx].vt = VALTYPE_UNSUPPORTED;
+        {
+          valuetable[validx].vt = VALTYPE_UNSUPPORTED;
+          memset (&valuetable[validx].value, 0,
+                  sizeof valuetable[validx].value);
+        }
     }
   for (argidx=0; argidx < argspecs_len; argidx++)
     {
@@ -1784,7 +1788,7 @@ dynamic_buffer_out (void *outfncarg, const char *buf, size_t buflen)
         {
           parm->error_flag = errno ? errno : ENOMEM;
           /* Wipe out what we already accumulated.  This is useful in
-             case sensitive data is formated.  */
+             case sensitive data is formatted.  */
           memset (parm->buffer, 0, parm->used);
           return -1;
         }
