@@ -39,7 +39,7 @@
 # include <pthread.h>
 #endif
 
-#include "gpg-error.h"
+#include "gpgrt-int.h"
 #include "lock.h"
 #include "posix-lock-obj.h"
 
@@ -103,7 +103,6 @@ use_pthread_p (void)
 #endif /*USE_POSIX_THREADS*/
 
 
-
 static _gpgrt_lock_t *
 get_lock_object (gpgrt_lock_t *lockhd)
 {
@@ -150,7 +149,7 @@ _gpgrt_lock_init (gpgrt_lock_t *lockhd)
     {
       rc = pthread_mutex_init (&lock->u.mtx, NULL);
       if (rc)
-        rc = gpg_err_code_from_errno (rc);
+        rc = _gpg_err_code_from_errno (rc);
     }
   else
     rc = 0; /* Threads are not used.  */
@@ -171,9 +170,11 @@ _gpgrt_lock_lock (gpgrt_lock_t *lockhd)
 #if USE_POSIX_THREADS
   if (use_pthread_p())
     {
+      _gpgrt_pre_syscall ();
       rc = pthread_mutex_lock (&lock->u.mtx);
       if (rc)
-        rc = gpg_err_code_from_errno (rc);
+        rc = _gpg_err_code_from_errno (rc);
+      _gpgrt_post_syscall ();
     }
   else
     rc = 0; /* Threads are not used.  */
@@ -196,7 +197,7 @@ _gpgrt_lock_trylock (gpgrt_lock_t *lockhd)
     {
       rc = pthread_mutex_trylock (&lock->u.mtx);
       if (rc)
-        rc = gpg_err_code_from_errno (rc);
+        rc = _gpg_err_code_from_errno (rc);
     }
   else
     rc = 0; /* Threads are not used.  */
@@ -219,7 +220,7 @@ _gpgrt_lock_unlock (gpgrt_lock_t *lockhd)
     {
       rc = pthread_mutex_unlock (&lock->u.mtx);
       if (rc)
-        rc = gpg_err_code_from_errno (rc);
+        rc = _gpg_err_code_from_errno (rc);
     }
   else
     rc = 0; /* Threads are not used.  */
@@ -244,7 +245,7 @@ _gpgrt_lock_destroy (gpgrt_lock_t *lockhd)
     {
       rc = pthread_mutex_destroy (&lock->u.mtx);
       if (rc)
-        rc = gpg_err_code_from_errno (rc);
+        rc = _gpg_err_code_from_errno (rc);
       else
         {
           /* Re-init the mutex so that it can be re-used.  */
